@@ -194,10 +194,10 @@ class EthereumNFTWatcher:
         Wait for the node to stop syncing.
         """
         self.logger.info('Waiting for node to stop syncing.')
-        syncing_done = False
-        while not syncing_done:
+        syncing = True
+        while syncing:
             sleep(1)
-            syncing_done = self._send_json_rpc('eth_syncing', [])
+            syncing = self._send_json_rpc('eth_syncing', [])
         self.logger.info('Server sync complete, start fetching.')
 
     def fetch_nfts_until_block(self,
